PALM-meteo: palmmeteo.plugins.VInterpPluginMixin Class Reference

PALM-meteo

Loading...
Searching...
No Matches
Public Member Functions | List of all members
palmmeteo.plugins.VInterpPluginMixin Class Reference
Inheritance diagram for palmmeteo.plugins.VInterpPluginMixin:
[legend]
Collaboration diagram for palmmeteo.plugins.VInterpPluginMixin:
[legend]

## Public Member Functions
| interpolate_vert (self, *args, **kwargs)
Public Member Functions inherited from palmmeteo.plugins.Plugin
| check_config (self, *args, **kwargs)
Public Member Functions inherited from palmmeteo.plugins.PluginMeta
| __new__ (cls, name, bases, dct)

## Detailed Description

    Base class mixin for plugins importing data.
    Registers 'interpolate_vert' method as a handler for event 'vinterp'.

    Abstract methods required to be implemented by derived classes:
        interpolate_vert

## Member Function Documentation

## ◆ interpolate_vert()

palmmeteo.plugins.VInterpPluginMixin.interpolate_vert | ( |  | self,
|  | * | args,
|  | ** | kwargs
| ) |  |

Reimplemented in palmmeteo_stdplugins.aladin.AladinPlugin, palmmeteo_stdplugins.cams.CAMSPlugin, palmmeteo_stdplugins.camx.CAMxPlugin, palmmeteo_stdplugins.icon.IconPlugin, palmmeteo_stdplugins.synthetic.SyntheticPlugin, and palmmeteo_stdplugins.wrf.WRFPlugin.

The documentation for this class was generated from the following file:

- palmmeteo/plugins.py